middleware

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthMiddleware

func AuthMiddleware(next http.Handler) http.Handler

Must come before middleware that changes the request (e.g., NormalizeMiddleware)

func CompressionMiddleware

func CompressionMiddleware(next http.Handler) http.Handler

func GetRequestAccessKey

func GetRequestAccessKey(r *http.Request) string

func LoggingMiddleware

func LoggingMiddleware(next http.Handler) http.Handler

Tracks request time and logs request after all handlers

func NormalizationMiddleware

func NormalizationMiddleware(next http.Handler) http.Handler

func WithIAM

func WithIAM(action iam.Action, next http.Handler) http.Handler

Types

type Middleware

type Middleware func(http.Handler) http.Handler

func Stack

func Stack(mw ...Middleware) Middleware

Jump to